pub struct KeyError {
pub byte: u8,
pub error_code: ErrorCodes,
}Fields
byte: u8The byte being processed when the error occurred. Do not depend on this field as it can vary wildly because not all characters occupy a single byte in memory. Rather this should be used as a context clue to help determine the issue.
error_code: ErrorCodesType of error that occurred.